El objeto de salida es un data set con los id dediscursos disponibles para usar como par<U+00E1>metro con
con get_speech. Cuando el par<U+00E1>metro es viewer = FALSE, devuelve un tibble con class "tbl_df","tbl","data.frame", y
cuando es viewer = TRUE devuelve un objeto con class "datatables","htmlwidget"
(The output is a data set with speeches id needed as parameters in get_speech.
When parameter is set to viewer = FALSE it returns a tibble and when it is viewer = TRUE it returns an
object of class "datatables","htmlwidget").